==> firebase_ui_localizations-1.6.1.tar.gz: lib/src/lang/it.dart <==
// Copyright 2023, the Chromium project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
import '../default_localizations.dart';

class ItLocalizations extends FirebaseUILocalizationLabels {
  const ItLocalizations();

  @override
  String get accessDisabledErrorText =>
      "L'accesso a questo account è stato temporaneamente disabilitato";

  @override
  String get arrayLabel => "array";

  @override
  String get booleanLabel => "boolean";

  @override
  String get cancelLabel => "cancel";

  @override
  String get chooseACountry => "Scegli un paese";

  @override
  String get confirmPasswordDoesNotMatchErrorText =>
      "Le password non coincidono";

  @override
  String get confirmPasswordInputLabel => "Conferma password";

  @override
  String get confirmPasswordIsRequiredErrorText => "Conferma la password";

  @override
  String get continueText => "Continua";

  @override
  String get countryCode => "Codice";

  @override
  String get credentialAlreadyInUseErrorText =>
      "Questo provider è già associato a un altro account utente.";

  @override
  String get deleteAccount => "Elimina account";

  @override
  String get differentMethodsSignInTitleText =>
      "Utilizzare uno dei seguenti metodi per accedere";

  @override
  String get disable => "Disabilita";

  @override
  String get eastInitialLabel => "E";

  @override
  String get emailInputLabel => "Email";

  @override
  String get emailIsRequiredErrorText => "L'email è obbligatoria";

  @override
  String get emailLinkSignInButtonLabel => "Accedi con il link magico";

  @override
  String get emailTakenErrorText => "L'account con questo email esiste già";

  @override
  String get enable => "Abilita";

  @override
  String get enableMoreSignInMethods => "Abilita altri metodi di accesso";

  @override
  String get enterSMSCodeText => "Inserisci il codice dell'SMS";

  @override
  String get findProviderForEmailTitleText =>
      "Inserisci l'email per continuare";

  @override
  String get forgotPasswordButtonLabel => "Password dimenticata?";

  @override
  String get forgotPasswordHintText =>
      "Inserisci il tuo indirizzo email e ti invieremo un link che ti consentirà di reimpostare la password";

  @override
  String get forgotPasswordViewTitle => "Password dimenticata";

  @override
  String get geopointLabel => "punto geografico";

  @override
  String get goBackButtonLabel => "Indietro";

  @override
  String get invalidCountryCode => "Codice non valido";

  @override
  String get isNotAValidEmailErrorText => "Fornisci un indirizzo email valido";

  @override
  String get latitudeLabel => "latitude";

  @override
  String get linkEmailButtonText => "Avanti";

  @override
  String get longitudeLabel => "longitude";

  @override
  String get mapLabel => "map";

  @override
  String get mfaTitle => "Verifica in due passaggi";

  @override
  String get name => "Nome";

  @override
  String get northInitialLabel => "N";

  @override
  String get nullLabel => "null";

  @override
  String get numberLabel => "number";

  @override
  String get off => "Off";

  @override
  String get on => "On";

  @override
  String get passwordInputLabel => "Password";

  @override
  String get passwordIsRequiredErrorText => "La password è obbligatoria";

  @override
  String get passwordResetEmailSentText =>
      "Ti abbiamo inviato un'email con un link per reimpostare la password. Controlla la posta.";

  @override
  String get phoneInputLabel => "Numero di telefono";

  @override
  String get phoneNumberInvalidErrorText => "Numero di telefono non valido";

  @override
  String get phoneNumberIsRequiredErrorText =>
      "Il numero di telefono è obbligatorio";

  @override
  String get phoneVerificationViewTitleText =>
      "Inserisci il tuo numero di telefono";

  @override
  String get profile => "Profilo";

  @override
  String get provideEmail => "Fornisci email e password";

  @override
  String get referenceLabel => "reference";

  @override
  String get registerActionText => "Registra";

  @override
  String get registerHintText => "Non hai un account?";

  @override
  String get registerText => "Registra";

  @override
  String get resetPasswordButtonLabel => "Reimposta password";

  @override
  String get sendLinkButtonLabel => "Invia link magico";

  @override
  String get signInActionText => "Accedi";

  @override
  String get signInHintText => "Hai già un account?";

  @override
  String get signInMethods => "Metodi di accesso";

  @override
  String get signInText => "Accedi";

  @override
  String get signInWithAppleButtonText => "Accedi con Apple";

  @override
  String get signInWithEmailLinkSentText =>
      "Ti abbiamo inviato un'email con un link magico Controlla la tua email e segui il link per accedere";

  @override
  String get signInWithEmailLinkViewTitleText => "Accedi con il link magico";

  @override
  String get signInWithFacebookButtonText => "Accedi con Facebook";

  @override
  String get signInWithGoogleButtonText => "Accedi con Google";

  @override
  String get signInWithPhoneButtonText => "Accedi con il telefono";

  @override
  String get signInWithTwitterButtonText => "Accedi con Twitter";

  @override
  String get signOutButtonText => "Esci";

  @override
  String get smsAutoresolutionFailedError =>
      "Impossibile risolvere automaticamente il codice SMS. Inserisci il codice manualmente";

  @override
  String get southInitialLabel => "S";

  @override
  String get stringLabel => "string";

  @override
  String get timestampLabel => "timestamp";

  @override
  String get typeLabel => "type";

  @override
  String get unknownError => "Si è verificato un errore sconosciuto";

  @override
  String get updateLabel => "update";

  @override
  String get userNotFoundErrorText => "L'account non esiste";

  @override
  String get valueLabel => "value";

  @override
  String get verifyCodeButtonText => "Verifica";

  @override
  String get verifyingSMSCodeText => "Verifica del codice SMS in corso…";

  @override
  String get verifyItsYouText => "Conferma la tua identità";

  @override
  String get verifyPhoneNumberButtonText => "Avanti";

  @override
  String get westInitialLabel => "W";

  @override
  String get wrongOrNoPasswordErrorText =>
      "La password non è valida o l'utente non dispone di una password";

  @override
  String get uploadButtonText => "Upload file";

  @override
  String get verifyEmailTitle => "Verify your email";

  @override
  String get verificationEmailSentText =>
      "A verification email has been sent to your email address. Please check your email and click on the link to verify your email address.";

  @override
  String get verificationFailedText =>
      "We couldn't verify your email address. ";

  @override
  String get resendVerificationEmailButtonLabel => "Resend verification email";

  @override
  String get verificationEmailSentTextShort => "Verification email sent";

  @override
  String get emailIsNotVerifiedText => "Email is not verified";

  @override
  String get waitingForEmailVerificationText =>
      "Waiting for email verification";

  @override
  String get dismissButtonLabel => "Dismiss";

  @override
  String get okButtonLabel => "OK";

  @override
  String get checkEmailHintText =>
      "Please check your email and click the link to verify your email address.";

  @override
  String get doneButtonLabel => "Done";

  @override
  String get invalidVerificationCodeErrorText =>
      "The code you entered is invalid. Please try again.";
}

==> firebase_ui_localizations-1.7.0.tar.gz: lib/src/lang/it.dart <==
// Copyright 2023, the Chromium project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
import '../default_localizations.dart';

class ItLocalizations extends FirebaseUILocalizationLabels {
  const ItLocalizations();

  @override
  String get accessDisabledErrorText =>
      "L'accesso a questo account è stato temporaneamente disabilitato";

  @override
  String get arrayLabel => "array";

  @override
  String get booleanLabel => "boolean";

  @override
  String get cancelLabel => "annulla";

  @override
  String get chooseACountry => "Scegli un paese";

  @override
  String get confirmPasswordDoesNotMatchErrorText =>
      "Le password non coincidono";

  @override
  String get confirmPasswordInputLabel => "Conferma password";

  @override
  String get confirmPasswordIsRequiredErrorText => "Conferma la password";

  @override
  String get continueText => "Continua";

  @override
  String get countryCode => "Codice";

  @override
  String get credentialAlreadyInUseErrorText =>
      "Questo provider è già associato a un altro account utente.";

  @override
  String get deleteAccount => "Elimina account";

  @override
  String get differentMethodsSignInTitleText =>
      "Utilizzare uno dei seguenti metodi per accedere";

  @override
  String get disable => "Disabilita";

  @override
  String get eastInitialLabel => "E";

  @override
  String get emailInputLabel => "Email";

  @override
  String get emailIsRequiredErrorText => "L'email è obbligatoria";

  @override
  String get emailLinkSignInButtonLabel => "Accedi con il link magico";

  @override
  String get emailTakenErrorText => "L'account con questo email esiste già";

  @override
  String get enable => "Abilita";

  @override
  String get enableMoreSignInMethods => "Abilita altri metodi di accesso";

  @override
  String get enterSMSCodeText => "Inserisci il codice dell'SMS";

  @override
  String get findProviderForEmailTitleText =>
      "Inserisci l'email per continuare";

  @override
  String get forgotPasswordButtonLabel => "Password dimenticata?";

  @override
  String get forgotPasswordHintText =>
      "Inserisci il tuo indirizzo email e ti invieremo un link che ti consentirà di reimpostare la password";

  @override
  String get forgotPasswordViewTitle => "Password dimenticata";

  @override
  String get geopointLabel => "punto geografico";

  @override
  String get goBackButtonLabel => "Indietro";

  @override
  String get invalidCountryCode => "Codice non valido";

  @override
  String get isNotAValidEmailErrorText => "Fornisci un indirizzo email valido";

  @override
  String get latitudeLabel => "latitude";

  @override
  String get linkEmailButtonText => "Avanti";

  @override
  String get longitudeLabel => "longitude";

  @override
  String get mapLabel => "map";

  @override
  String get mfaTitle => "Verifica in due passaggi";

  @override
  String get name => "Nome";

  @override
  String get northInitialLabel => "N";

  @override
  String get nullLabel => "null";

  @override
  String get numberLabel => "number";

  @override
  String get off => "Off";

  @override
  String get on => "On";

  @override
  String get passwordInputLabel => "Password";

  @override
  String get passwordIsRequiredErrorText => "La password è obbligatoria";

  @override
  String get passwordResetEmailSentText =>
      "Ti abbiamo inviato un'email con un link per reimpostare la password. Controlla la posta.";

  @override
  String get phoneInputLabel => "Numero di telefono";

  @override
  String get phoneNumberInvalidErrorText => "Numero di telefono non valido";

  @override
  String get phoneNumberIsRequiredErrorText =>
      "Il numero di telefono è obbligatorio";

  @override
  String get phoneVerificationViewTitleText =>
      "Inserisci il tuo numero di telefono";

  @override
  String get profile => "Profilo";

  @override
  String get provideEmail => "Fornisci email e password";

  @override
  String get referenceLabel => "reference";

  @override
  String get registerActionText => "Registra";

  @override
  String get registerHintText => "Non hai un account?";

  @override
  String get registerText => "Registra";

  @override
  String get resetPasswordButtonLabel => "Reimposta password";

  @override
  String get sendLinkButtonLabel => "Invia link magico";

  @override
  String get signInActionText => "Accedi";

  @override
  String get signInHintText => "Hai già un account?";

  @override
  String get signInMethods => "Metodi di accesso";

  @override
  String get signInText => "Accedi";

  @override
  String get signInWithAppleButtonText => "Accedi con Apple";

  @override
  String get signInWithEmailLinkSentText =>
      "Ti abbiamo inviato un'email con un link magico Controlla la tua email e segui il link per accedere";

  @override
  String get signInWithEmailLinkViewTitleText => "Accedi con il link magico";

  @override
  String get signInWithFacebookButtonText => "Accedi con Facebook";

  @override
  String get signInWithGoogleButtonText => "Accedi con Google";

  @override
  String get signInWithPhoneButtonText => "Accedi con il telefono";

  @override
  String get signInWithTwitterButtonText => "Accedi con Twitter";

  @override
  String get signOutButtonText => "Esci";

  @override
  String get smsAutoresolutionFailedError =>
      "Impossibile risolvere automaticamente il codice SMS. Inserisci il codice manualmente";

  @override
  String get southInitialLabel => "S";

  @override
  String get stringLabel => "string";

  @override
  String get timestampLabel => "timestamp";

  @override
  String get typeLabel => "tipo";

  @override
  String get unknownError => "Si è verificato un errore sconosciuto";

  @override
  String get updateLabel => "aggiorna";

  @override
  String get userNotFoundErrorText => "L'account non esiste";

  @override
  String get valueLabel => "valore";

  @override
  String get verifyCodeButtonText => "Verifica";

  @override
  String get verifyingSMSCodeText => "Verifica del codice SMS in corso…";

  @override
  String get verifyItsYouText => "Conferma la tua identità";

  @override
  String get verifyPhoneNumberButtonText => "Avanti";

  @override
  String get westInitialLabel => "W";

  @override
  String get wrongOrNoPasswordErrorText =>
      "La password non è valida o l'utente non dispone di una password";

  @override
  String get uploadButtonText => "Invia file";

  @override
  String get verifyEmailTitle => "Verifica la tua email";

  @override
  String get verificationEmailSentText =>
      "Una mail di verifica è stata inviata al tuo indirizzo email. Prego controlla la tua email e clicca sul link per verificare il tuo indirizzo email.";

  @override
  String get verificationFailedText =>
      "Non possiamo verificare il tuo indirizzo email. ";

  @override
  String get resendVerificationEmailButtonLabel => "Reinvia email di verifica";

  @override
  String get verificationEmailSentTextShort => "Email di verifica inviata";

  @override
  String get emailIsNotVerifiedText => "L'email non è stata verificata";

  @override
  String get waitingForEmailVerificationText =>
      "In attesa della verifica dell'email";

  @override
  String get dismissButtonLabel => "Dismetti";

  @override
  String get okButtonLabel => "OK";

  @override
  String get checkEmailHintText =>
      "Prego controlla la tua email e clicca il link per verificare il tuo indirizzo email.";

  @override
  String get doneButtonLabel => "Fatto";

  @override
  String get invalidVerificationCodeErrorText =>
      "Il codice che hai inserito non è valido. Prego riprova ancora.";

  @override
  String get ulinkProviderAlertTitle => "Unlink provider";

  @override
  String get confirmUnlinkButtonLabel => "Unlink";

  @override
  String get cancelButtonLabel => "Cancel";

  @override
  String get unlinkProviderAlertMessage =>
      "Are you sure you want to unlink this provider?";
}
